; ***********************************************************************
; * NORMGEN macro *******************************************************
; ***********************************************************************
; * Function: NORMGEN generates n x p-dimensional normal variates with  *
; *                   mean mu and covariance sigma.                     *
; *                                                                     *
; * Call:     x = NORMGEN (n mu sigma)                                  *
; *                                                                     *
; * ->X       n            scalar                                       *
; *           mu    p x 1  matrix                                       *
; *           sigma p x p  matrix                                       *
; * X->       x     n x p  matrix                                       *
; *                                                                     *
; * Example:  FUNC("examples\MVAnormgen")                                  *
; *           mu = #(1 1)                                               *
; *           sigma = #(2 1, 1 3)                                       *
; *           x = NORMGEN(200 mu sigma)                                 *
; *           gives 200 two dimensional normal random variables with    *
; *           mean mu and covariance sigma.                             *
; *                                                                     *
; * See also: EIGSM   (command)                                         *
; *                                                                     *
; ***********************************************************************
; ** Sigbert Klinke, 910307 *********************************************
; ***********************************************************************
proc (x)=MVAnormgen(n mu sigma)
  error(cols(sigma)<>rows(sigma) "NORMGEN: COLS <> ROWS")
  error(.!(sigma'-sigma==0) "NORMGEN: SIGMA NONSYMMETRIC")
  p=cols(sigma)                      ; determine dimension
  (a b)=eigsm(sigma)                 ; spectral decomposition
  c=a~TRN(b)
  c=SORT(c)
  e=sqrt(c[,1])                      ; take squareroot of eigenvalues
  v=trn(c[,2:cols(c)])               ; eigenvectors
  sigma2=v*diag(e)*v'                ; squareroot of sigma
  y=normal(n p)
  x=y*sigma2'                        ; transformation to cov sigma
  x=x+matrix(n)*mu'                  ; shift by mean
endp
; ***********************************************************************
